=== modified file 'libravatar/account/models.py'
--- libravatar/account/models.py	2011-04-02 10:08:03 +0000
+++ libravatar/account/models.py	2011-04-10 03:59:30 +0000
@@ -100,7 +100,7 @@
 class PhotoManager(models.Manager):
     def delete_user_photos(self, user):
         for photo in self.filter(user=user):
-            photo.delete() # deletes the photo on disk as well
+            photo.delete(delete_file_on_disk=False)
 
 class Photo(models.Model):
     user = models.ForeignKey(User, related_name='photos')
@@ -131,20 +131,21 @@
         rename(tmp_filename, dest_filename)
         return True
 
-    def delete(self):
+    def delete(self, delete_file_on_disk=True):
         # Remove links to this photo
         for email in self.emails.all():
             email.set_photo(None)
         for openid in self.openids.all():
             openid.set_photo(None)
 
-        # Queue a job for the photo deletion gearman worker
-        gm_client = libgearman.Client()
-        for server in settings.GEARMAN_SERVERS:
-            gm_client.add_server(server)
+        if delete_file_on_disk:
+            # Queue a job for the photo deletion gearman worker
+            gm_client = libgearman.Client()
+            for server in settings.GEARMAN_SERVERS:
+                gm_client.add_server(server)
 
-        workload = {'file_hash': self.filename, 'format': self.format}
-        gm_client.do_background('deletephoto', json.dumps(workload))
+            workload = {'file_hash': self.filename, 'format': self.format}
+            gm_client.do_background('deletephoto', json.dumps(workload))
 
         super(Photo, self).delete()
 

=== modified file 'libravatar/account/views.py'
--- libravatar/account/views.py	2011-04-09 11:27:25 +0000
+++ libravatar/account/views.py	2011-04-10 03:59:30 +0000
@@ -548,11 +548,13 @@
     if request.method == 'POST':
         form = DeleteAccountForm(request.user, request.POST)
         if form.is_valid():
+            username = request.user.username
             download_url = _perform_export(request.user, True)
             Photo.objects.delete_user_photos(request.user)
             request.user.delete() # cascading through unconfirmed and confirmed emails
             logout(request)
-            return render_to_response('account/delete_done.html', {'download_url': download_url},
+            return render_to_response('account/delete_done.html',
+                                      {'download_url': download_url, 'username': username},
                                       context_instance=RequestContext(request))
     else:
         form = DeleteAccountForm(request.user)

=== modified file 'libravatar/exportaccount.py'
--- libravatar/exportaccount.py	2011-04-10 03:51:57 +0000
+++ libravatar/exportaccount.py	2011-04-10 03:59:30 +0000
@@ -17,6 +17,7 @@
 # along with Libravatar.  If not, see <http://www.gnu.org/licenses/>.
 
 import base64
+from gearman import libgearman
 import gzip
 import json
 import os
@@ -117,9 +118,15 @@
     destination.write(xml_footer())
     destination.close()
 
-    if do_delete:
-        # TODO: kick off a photo deletion worker
-        pass
+    if do_delete: # Delete files on disk
+        gm_client = libgearman.Client()
+        for server in settings.GEARMAN_SERVERS:
+            gm_client.add_server(server)
+
+        for photo in photos:
+            (photo_filename, photo_format) = photo
+            workload = {'file_hash': photo_filename, 'format': photo_format}
+            gm_client.do_background('deletephoto', json.dumps(workload))
 
     return 0
 

=== modified file 'libravatar/templates/account/delete_done.html'
--- libravatar/templates/account/delete_done.html	2011-04-06 10:03:08 +0000
+++ libravatar/templates/account/delete_done.html	2011-04-10 03:59:30 +0000
@@ -10,7 +10,7 @@
 <p>In case you want to take your data with you, it's currenlty being exported and will be <b>ready in a few moments</b>:</p>
 
 <ul>
-  <li><a href="{{download_url}}">{{user.username}}.xml.gz</a></li>
+  <li><a href="{{download_url}}">{{username}}.xml.gz</a></li>
 </ul>
 
 <p><i>This export will be deleted in a few hours.</i></p>

